@@ -82,9 +82,12 @@ class Manifest(object):
     the string representation of the target object
     """
 
-    def __init__(self, raw_manifest, namespace=None, logger='sprinter'):
+    def __init__(self, raw_manifest, namespace=None, logger='sprinter',
+                 username=None, password=None):
         self.logger = logging.getLogger(logger)
-        self.manifest = self.__load_manifest(raw_manifest)
+        self.manifest = self.__load_manifest(raw_manifest,
+                                             username=username,
+                                             password=password)
         self.namespace = namespace if namespace else self.__parse_namespace()
 
     def source(self):
@@ -94,12 +97,17 @@ class Manifest(object):
         return self.get('config', 'source') if \
             self.has_option('config', 'source') else None
 
-    def __load_manifest(self, raw_manifest):
+    def __load_manifest(self, raw_manifest, username=None, password=None):
         manifest = RawConfigParser()
         manifest.add_section('config')
         if type(raw_manifest) == str:
             if raw_manifest.startswith("http"):
-                manifest_file_handler = StringIO(urllib.urlopen(raw_manifest).read())
+                if username and password:
+                    manifest_file_handler = StringIO(lib.authenticated_get(username,
+                                                                           password,
+                                                                           raw_manifest))
+                else:
+                    manifest_file_handler = StringIO(urllib.urlopen(raw_manifest).read())
                 manifest.readfp(manifest_file_handler)
             else:
                 manifest.read(raw_manifest)
