@@ -24,15 +24,15 @@ class RecipeStandard(RecipeBase):
         if 'rc' in config:
             self.directory.add_to_rc(config['rc'])
         if 'command' in config:
-            self.logger.info(lib.call(config['command']))
+            self.logger.info(lib.call(config['command'], bash=True))
 
     def update(self, feature_name, config):
         """ Setup performs the setup required, and works with the old
         config is destruction is required """
-        if 'rc' in config:
-            self.directory.add_to_rc(config['rc'])
+        if 'rc' in config['target']:
+            self.directory.add_to_rc(config['target']['rc'])
         if 'command' in config['target']:
-            self.logger.info(lib.call(config['target']['command']))
+            self.logger.info(lib.call(config['target']['command'], bash=True))
 
     def destroy(self, feature_name, config):
         """ Destroys an old feature if it is no longer required """
